==> kdegraphics-4.1.2.tar.bz2: kdegraphics-4.1.2/gwenview/app/fullscreencontent.h <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
/*
Gwenview: an image viewer
Copyright 2008 Aurélien Gâteau <aurelien.gateau@free.fr>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
#ifndef FULLSCREENCONTENT_H
#define FULLSCREENCONTENT_H

// Qt
#include <QWidget>

// KDE

// Local

class QStringList;

class KActionCollection;
class KUrl;

namespace Gwenview {

class SlideShow;

class ThumbnailBarView;


class FullScreenContentPrivate;
/**
 * The content of the fullscreen bar
 */
class FullScreenContent : public QObject {
	Q_OBJECT
public:
	FullScreenContent(QWidget* parent, KActionCollection*, SlideShow*);
	~FullScreenContent();

	ThumbnailBarView* thumbnailBar() const;

	void setCurrentUrl(const KUrl&);

protected:
	bool eventFilter(QObject*, QEvent*);

private Q_SLOTS:
	void updateInformationLabel();
	void updateMetaInfoDialog();
	void configureInformationLabel();
	void slotPreferredMetaInfoKeyListChanged(const QStringList& list);
	void showFullScreenConfigDialog();
	void updateSlideShowIntervalLabel();
	void setCurrentFullScreenTheme(const QString& themeName);
	void setFullScreenBarHeight(int value);

private:
	FullScreenContentPrivate* const d;
};


} // namespace

#endif /* FULLSCREENCONTENT_H */

==> kdegraphics-4.6.3.tar.bz2: kdegraphics-4.6.3/gwenview/app/fullscreencontent.h <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
/*
Gwenview: an image viewer
Copyright 2008 Aurélien Gâteau <agateau@kde.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
#ifndef FULLSCREENCONTENT_H
#define FULLSCREENCONTENT_H

// Qt
#include <QWidget>

// KDE

// Local

class QStringList;

class KActionCollection;
class KUrl;

namespace Gwenview {

class FullScreenBar;
class SlideShow;

class ThumbnailBarView;


struct FullScreenContentPrivate;
/**
 * The content of the fullscreen bar
 */
class FullScreenContent : public QObject {
	Q_OBJECT
public:
	FullScreenContent(FullScreenBar* parent, KActionCollection*, SlideShow*);
	~FullScreenContent();

	ThumbnailBarView* thumbnailBar() const;

	void setCurrentUrl(const KUrl&);

protected:
	bool eventFilter(QObject*, QEvent*);

private Q_SLOTS:
	void updateInformationLabel();
	void updateMetaInfoDialog();
	void showImageMetaInfoDialog();
	void slotPreferredMetaInfoKeyListChanged(const QStringList& list);
	void showFullScreenConfigDialog();
	void updateSlideShowIntervalLabel();
	void setCurrentFullScreenTheme(const QString& themeName);
	void setFullScreenBarHeight(int value);
	void enableAutoHiding();
	void slotShowThumbnailsToggled(bool value);

private:
	FullScreenContentPrivate* const d;
};


} // namespace

#endif /* FULLSCREENCONTENT_H */
